import 'dart:async';

import 'package:c8y_client/src/alarms/implementations/alarm_collection_impl.dart';
import 'package:c8y_client/src/alarms/model/alarm_api.dart';
import 'package:c8y_client/src/alarms/model/alarm_media_type.dart';
import 'package:c8y_client/src/alarms/model/alarm_representation.dart';
import 'package:c8y_client/src/core/model/id.dart';
import 'package:c8y_client/src/sdk/client/rest_connector.dart';

class Alarm implements AlarmApi {
  final RestConnector _restConnector;
  final int _pageSize;
  final String _path = '/alarm/alarms';
  final String _totalPages = 'withTotalPages=true';
  String _url;

  Alarm(this._restConnector, this._pageSize, String host) {
    _url = host + _path;
  }

  @override
  Future<AlarmRepresentation> create(AlarmRepresentation alarm) async {
    var body = AlarmRepresentation.toJson(alarm);
    return await _restConnector.post(_url, body, AlarmRepresentation.fromJson);
  }

  @override
  Future<AlarmRepresentation> update(AlarmRepresentation alarm) {
    // TODO: implement update
    return null;
  }

  @override
  Future<AlarmRepresentation> get(ID id) async {
    return await _restConnector.get(
        _url + '/' + id.id, AlarmMediaType.ALARM, AlarmRepresentation.fromJson);
  }

  @override
  Future<List<AlarmRepresentation>> listByLimit(
      Map<String, Object> queryParams, int limit) async {
    var pagedCollection = await AlarmCollectionImpl(
        _restConnector, _url + '?' + _totalPages, _pageSize);
    var collection = await pagedCollection.get(queryParams);
    return getList(await collection.elements(limit));
  }

  Future<List<AlarmRepresentation>> getList(
      StreamIterator<AlarmRepresentation> iterator) async {
    var listTwoReturn = <AlarmRepresentation>[];
    while (await iterator.moveNext()) {
      listTwoReturn.add(iterator.current);
    }
    return listTwoReturn;
  }

  @override
  Future<List<AlarmRepresentation>> listAll(
      Map<String, Object> queryParams) async {
    return await getList(await stream(queryParams));
  }

  @override
  Future<StreamIterator<AlarmRepresentation>> stream(
      Map<String, Object> queryParams) async {
    var pagedCollection = await AlarmCollectionImpl(
        _restConnector, _url + '?' + _totalPages, _pageSize);
    var collection = await pagedCollection.get(queryParams);
    return collection.allPages();

  }
}
