import 'dart:async';

import 'package:c8y_client/src/core/model/base_collection.dart';
import 'package:c8y_client/src/core/model/paged_collection_resource.dart';
import 'package:logger/logger.dart';

class PagedCollectionStreamable<T, C extends BaseCollectionRepresentation<T>>
    with StreamIterator<T> {
  PagedCollectionResource collectionResource;
  C collection;
  var logger = Logger();
  int limit;
  int counter = 0;
  Stream<T> stream;
  StreamIterator<T> iterator;

  PagedCollectionStreamable(
      this.collectionResource, this.collection, this.limit) {
    stream = createStream(collection.iterator, collection, 1);
    iterator = StreamIterator<T>(stream);
  }

  Stream<T> createStream(Iterator iterator, C collection, int counter) async* {
    while (!reachedLimit(counter)) {
      if (iterator.moveNext()) {
        counter++;
        yield iterator.current;
      } else if (nextIsNull(collection)) {
        break;
      } else {
        collection = await collectionResource.getNextPage(collection);
        iterator = collection.iterator;
        counter++;
        yield* createStream(iterator, collection, counter);
      }
    }
  }

  bool nextIsNull(collection) {
    return collection.next == null;
  }

  bool reachedLimit(counter) {
    return limit > 0 && counter >= limit;
  }

  @override
  Future cancel() {
    // TODO: implement cancel
    return null;
  }

  @override
  T get current => iterator.current;

  @override
  Future<bool> moveNext() {
    return iterator.moveNext();
  }
}
