import 'id.dart';


abstract class Document<T extends ID> {
  T id;
  Map<String, Object> fragments;
  String self;

  void set(String propertyName, Object object) {
    _setProperty(object, propertyName);
  }

  Object get(String propertyName) {
    if (fragments.containsKey(propertyName)) {
      return fragments[propertyName];
    } else {
      return null;
    }
  }

  Document();

  Document.withID(this.id);

  Document.withFragments(this.id, Map<String, Object> fragments) {
    _add(fragments);
  }

  void _add(Map<String, Object> fragments) {
    if (fragments == null) {
      return;
    }
    for (var fragment in fragments.entries) {
      _setProperty(fragment.key, fragment.value);
    }
  }

  void _setProperty(String propertyName, Object object) {
    fragments.putIfAbsent(propertyName, object);
  }
}
